@@ -858,6 +858,12 @@ GVApi::logout(AsyncTaskToken *token)
         return false;
     }
 
+    if (!loggedIn) {
+        token->status = ATTS_NOT_LOGGED_IN;
+        token->emitCompleted ();
+        return true;
+    }
+
     bool rv = doGet(GV_HTTPS "/account/signout", token, this,
                     SLOT (onLogout(bool, const QByteArray&, void*)));
     Q_ASSERT(rv);
@@ -869,8 +875,11 @@ void
 GVApi::onLogout(bool /*success*/, const QByteArray & /*response*/, void *ctx)
 {
     AsyncTaskToken *token = (AsyncTaskToken *)ctx;
+
+    loggedIn = false;
+
     token->status = ATTS_SUCCESS;
-    token->emitCompleted ();;
+    token->emitCompleted ();
 }//GVApi::onLogout
 
 bool
@@ -881,6 +890,12 @@ GVApi::getPhones(AsyncTaskToken *token)
         return false;
     }
 
+    if (!loggedIn) {
+        token->status = ATTS_NOT_LOGGED_IN;
+        token->emitCompleted ();
+        return true;
+    }
+
     bool rv = doGet (GV_HTTPS "/b/0/settings/tab/phones", token, this,
                      SLOT (onGetPhones(bool, const QByteArray&, void*)));
     Q_ASSERT(rv);
@@ -1091,6 +1106,12 @@ GVApi::getInbox(AsyncTaskToken *token)
         return true;
     }
 
+    if (!loggedIn) {
+        token->status = ATTS_NOT_LOGGED_IN;
+        token->emitCompleted ();
+        return true;
+    }
+
     QString strLink = QString (GV_HTTPS "/b/0/inbox/recent/%1?page=p%2")
                         .arg(token->inParams["type"].toString())
                         .arg(token->inParams["page"].toString());
@@ -1478,6 +1499,12 @@ GVApi::callOut(AsyncTaskToken *token)
         return true;
     }
 
+    if (!loggedIn) {
+        token->status = ATTS_NOT_LOGGED_IN;
+        token->emitCompleted ();
+        return true;
+    }
+
     QUrl url(GV_HTTPS_M "/x");
     url.addQueryItem("m" , "call");
     url.addQueryItem("n" , token->inParams["destination"].toString());
@@ -1578,6 +1605,12 @@ GVApi::callBack(AsyncTaskToken *token)
         return true;
     }
 
+    if (!loggedIn) {
+        token->status = ATTS_NOT_LOGGED_IN;
+        token->emitCompleted ();
+        return true;
+    }
+
     if (rnr_se.isEmpty ()) {
         token->status = ATTS_AC_NOT_CONFIGURED;
         token->emitCompleted ();
@@ -1677,8 +1710,13 @@ GVApi::sendSms(AsyncTaskToken *token)
         return true;
     }
 
-    QUrl url(GV_HTTPS_M "/x");
+    if (!loggedIn) {
+        token->status = ATTS_NOT_LOGGED_IN;
+        token->emitCompleted ();
+        return true;
+    }
 
+    QUrl url(GV_HTTPS_M "/x");
     url.addQueryItem("m" , "sms");
     url.addQueryItem("n" , token->inParams["destination"].toString());
     url.addQueryItem("f" , "");
@@ -1789,6 +1827,12 @@ GVApi::getVoicemail(AsyncTaskToken *token)
         return true;
     }
 
+    if (!loggedIn) {
+        token->status = ATTS_NOT_LOGGED_IN;
+        token->emitCompleted ();
+        return true;
+    }
+
     QString strLink = QString (GV_HTTPS "/b/0/media/send_voicemail/%1")
                         .arg(token->inParams["vmail_link"].toString());
     return doGet(strLink, token, this, SLOT(onVmail(bool, QByteArray, void*)));
@@ -1857,6 +1901,12 @@ GVApi::markInboxEntryAsRead(AsyncTaskToken *token)
         return true;
     }
 
+    if (!loggedIn) {
+        token->status = ATTS_NOT_LOGGED_IN;
+        token->emitCompleted ();
+        return true;
+    }
+
     // This method call needs to also be added as content data
     QString strContent = QString("messages=%1&read=1&_rnr_se=%2")
                             .arg(token->inParams["id"].toString()).arg(rnr_se);
