@@ -176,15 +176,4 @@ private:
     friend class Singletons;
 };
 
-class MyXmlErrorHandler : public QAbstractMessageHandler
-{
-public:
-    MyXmlErrorHandler(QObject *parent = NULL);
-
-protected:
-    void handleMessage (QtMsgType type, const QString &description,
-                        const QUrl &identifier,
-                        const QSourceLocation &sourceLocation);
-};
-
 #endif //__GVWEBPAGE_H__
