@@ -31,6 +31,8 @@ Contact: yuvraaj@gmail.com
 #include <QtXml>
 #include <QtScript>
 
+#include "NwReqTracker.h"
+
 #ifdef QT_NO_DEBUG
 #define NO_DBGINFO      1
 #else
@@ -44,15 +46,27 @@ Contact: yuvraaj@gmail.com
 #define SKYPE_CLIENT_NAME "qgvdial"
 
 #define UA_N900   "Mozilla/5.0 (X11; U; Linux armv7l; en-GB; rv:1.9.2a1pre) Gecko/20090928 Firefox/3.5 Maemo Browser 1.4.1.21 RX-51 N900"
-#define UA_IPHONE "Mozilla/5.0 (iPhone; U; CPU iPhone OS 3_0 like Mac OS X; en-us) AppleWebKit/528.18 (KHTML, like Gecko) Version/4.0 Mobile/7A341 Safari/528.16"
+#define UA_IPHONE  "Mozilla/5.0 (iPhone; U; CPU iPhone OS 3_0 like Mac OS X; en-us) AppleWebKit/528.18 (KHTML, like Gecko) Version/4.0 Mobile/7A341 Safari/528.16"
+#define UA_IPHONE4 "Mozilla/5.0 (iPhone; U; CPU iPhone OS 4_3_1 like Mac OS X; zh-tw) AppleWebKit/533.17.9 (KHTML, like Gecko) Version/5.0.2 Mobile/8G4 Safari/6533.18.5"
+#define UA_IPOD    "Mozilla/5.0 (iPod; U; CPU iPhone OS 4_3_3 like Mac OS X; ja-jp) AppleWebKit/533.17.9 (KHTML, like Gecko) Version/5.0.2 Mobile/8J2 Safari/6533.18.5"
 #define UA_DESKTOP "Mozilla/5.0 (X11; Linux x86_64; rv:5.0) Gecko/20100101 Firefox/5.0"
 
 #define GV_URL          "http://www.google.com/voice"
 #define GV_HTTPS        "https://www.google.com/voice"
 #define GV_HTTPS_M      "https://www.google.com/voice/m"
 
+#define GOOGLE_ACCOUNTS         "https://accounts.google.com"
+#define GV_ACCOUNT_SERVICELOGIN GOOGLE_ACCOUNTS "/ServiceLogin"
+#define GV_ACCOUNT_SMSAUTH      GOOGLE_ACCOUNTS "/SmsAuth"
+
+#define GOOGLE_SERVICELOGIN "https://www.google.com/accounts/ServiceLogin"
+#define GV_SERVICELOGIN_PARAMS "?nui=5&service=grandcentral&ltmpl=mobile&btmpl=mobile&passive=true&continue="
+
 #define GV_CLIENTLOGIN "https://www.google.com/accounts/ClientLogin"
 
+#define Q_DEBUG(_s) qDebug() << QString("%1(%2): %3").arg(__FUNCTION__).arg(__LINE__).arg(_s)
+#define Q_WARN(_s) qWarning() << QString("%1(%2): %3").arg(__FUNCTION__).arg(__LINE__).arg(_s)
+
 struct GVRegisteredNumber
 {
     QString     strId;
@@ -79,6 +93,18 @@ enum GVI_Entry_Type {
     GVIE_TextMessage,
 };
 
+struct ConversationEntry {
+    QString from;
+    QString time;
+    QString text;
+
+    void init() {
+        from.clear ();
+        time.clear ();
+        text.clear ();
+    }
+};
+
 struct GVInboxEntry
 {
     QString         id;
@@ -89,6 +115,8 @@ struct GVInboxEntry
     QString         strPhoneNumber;
     QString         strText;
 
+    QVector<ConversationEntry> conversation;
+
     QString         strNote;
 
     bool            bRead;
@@ -107,6 +135,7 @@ struct GVInboxEntry
         strDisplayNumber.clear ();
         strPhoneNumber.clear ();
         strText.clear ();
+        conversation.clear ();
         strNote.clear ();
 
         bRead = bSpam = bTrash = bStar = false;
@@ -279,5 +308,7 @@ extern int   logLevel;   //! Log level
 #define MOBILITY_PRESENT 1
 #endif
 
+#include "AsyncTaskToken.h"
+
 #endif //__cplusplus
 #endif //__GLOBAL_H__
